@@ -146,6 +146,8 @@ class AddonsLoader:
 
     async def discover_addons(self, send_event=True):
         for filepath in await self.files_repo.list(self.addons_path):
+            if filepath.is_dir():
+                continue
             await self._discover_addon(filepath.name, send_event=send_event)
 
     async def delete_addon(self, filename: str):
