@@ -66,11 +66,12 @@ GenericRequestHandler = TypeVar('GenericRequestHandler', bound=ExtRequestHandler
 
 
 class ChainRequestHandler(ExtRequestHandler):
-
     def __call__(self, target: HandlerType):
         @wraps(target)
         async def f(*args, **kwargs):
             req: Request = args[0]
+            if len(args) > 1:
+                kwargs['ws'] = args[1]
             prot_identity = await self.protector(req, self.container) if self.protector else None
             if self.in_struct:
                 validated = self.validation_fnc(self.in_struct, req)
@@ -93,7 +94,7 @@ class ChainRequestHandler(ExtRequestHandler):
                         await plugin.exec_after(context=incoming, container=self.container, target_result=ret_val)
             else:
                 ret_val = await target(incoming, self.container)
-            if isinstance(ret_val, HTTPResponse) or isinstance(ret_val, ResponseStream):
+            if isinstance(ret_val, (HTTPResponse, ResponseStream)):
                 return ret_val
             return self.response_fabric(ret_val)
 
