@@ -7,6 +7,9 @@ from base64 import b64encode, b64decode
 from typing import Iterable
 from uuid import uuid4
 
+from Crypto.Cipher import AES
+from Crypto.Random import get_random_bytes
+
 
 # from Crypto.Cipher import AES
 # from Crypto.Random import get_random_bytes
@@ -80,34 +83,28 @@ class AESCrypto(BaseCrypto):
         self._key_len = 32
 
     def encrypt(self, plain_text: str) -> DataStruct:
-        pass
-        # salt = get_random_bytes(AES.block_size)
-        # private_key = hashlib.scrypt(
-        #    self._data_password.encode(), salt=salt, n=self._n_factor, r=self._block_size, p=self._threads_num,
-        #    dklen=self._key_len)
-        # cipher_config = AES.new(private_key, AES.MODE_GCM)
-        # cipher_text, tag = cipher_config.encrypt_and_digest(bytes(plain_text, sys.getdefaultencoding()))
-        # return AESCrypto.DataStruct(cipher_text, salt, cipher_config.nonce, tag)
+        salt = get_random_bytes(AES.block_size)
+        private_key = hashlib.scrypt(
+            self._data_password.encode(), salt=salt, n=self._n_factor, r=self._block_size, p=self._threads_num,
+            dklen=self._key_len)
+        cipher_config = AES.new(private_key, AES.MODE_GCM)
+        cipher_text, tag = cipher_config.encrypt_and_digest(bytes(plain_text, sys.getdefaultencoding()))
+        return AESCrypto.DataStruct(cipher_text, salt, cipher_config.nonce, tag)
 
     def decrypt(self, aes_struct: DataStruct) -> str:
-        pass
-        # aes_struct.decode()
-        # private_key = hashlib.scrypt(
-        #    self._data_password.encode(), salt=aes_struct.salt, n=self._n_factor, r=self._block_size,
-        #    p=self._threads_num,
-        #    dklen=self._key_len)
-        # cipher = AES.new(private_key, AES.MODE_GCM, nonce=aes_struct.nonce)
-        # decrypted = cipher.decrypt_and_verify(aes_struct.cipher_text, aes_struct.tag)
-        # return decrypted
+        aes_struct.decode()
+        private_key = hashlib.scrypt(
+            self._data_password.encode(), salt=aes_struct.salt, n=self._n_factor, r=self._block_size,
+            p=self._threads_num,
+            dklen=self._key_len)
+        cipher = AES.new(private_key, AES.MODE_GCM, nonce=aes_struct.nonce)
+        decrypted = cipher.decrypt_and_verify(aes_struct.cipher_text, aes_struct.tag)
+        return decrypted
 
     @property
     def key_len(self):
         return self._key_len
 
 
-if __name__ == '__main__':
-    cp = AESCrypto('asfasfsafasfsafsff')
-    crypted = cp.encrypt("asfasgfasghsdhalkfdhmamnfhk;msldhmlsa;'dmh;sldmh;lsmdl;hml;")
-    crypted.encode()
-    # decrypdted = cp.decrypt(crypted)
-    # print(crypted, "\n", decrypdted)
+class RsaCrypto(BaseCrypto):
+    pass
